#!/bin/sh
emacs_is_beta=
emacs_major_version=21
emacs_minor_version=4
emacs_beta_version=8
xemacs_codename="Honest Recruiter"
emacs_kitname=""
infodock_major_version=4
infodock_minor_version=0
infodock_build_version=8
